powered by
Login to your Map of Life account.
mol_login(email, password = NULL)
The email address associated with your Map of Life Account.
Your map of life password. If left blank, and you are in RStudio you can enter it via a secure popup.
No return value
# NOT RUN { mol_login("your.email@company.com") # }
Run the code above in your browser using DataLab